@@ -18,31 +18,36 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 import base64
 import logging
-
 import os
 from dataclasses import dataclass
 from pathlib import Path
-from typing import Dict, Optional, Any
+from typing import Any, Dict, Optional
 from urllib.parse import urlparse
 
-from gql import Client as GraphQLClient, gql
+from gql import Client as GraphQLClient
+from gql import gql
 from gql.transport.aiohttp import AIOHTTPTransport
 from graphql import DocumentNode, ExecutionResult
 
 from .client import (
-    Client,
+    BackendCheckResponse,
+    BackendError,
     BackendResponse,
     BulkUploadParams,
-    BackendCheckResponse,
+    BulkUploadResponse,
+    BulkUploadStatistics,
+    Client,
     DeleteDetectionsParams,
     DeleteDetectionsResponse,
     DeleteSavedQueriesParams,
     DeleteSavedQueriesResponse,
-    ListSchemasParams,
     ListManagedSchemasResponse,
-    BulkUploadResponse, BulkUploadStatistics, ManagedSchema, UpdateManagedSchemaParams,
+    ListSchemasParams,
+    ManagedSchema,
+    PantherSDKBulkUploadParams,
+    PantherSDKBulkUploadResponse,
+    UpdateManagedSchemaParams,
     UpdateManagedSchemaResponse,
-    BackendError, ConfigSDKBulkUploadParams, ConfigSDKBulkUploadResponse
 )
 
 
@@ -77,7 +82,7 @@ class PublicAPIRequests:
     def delete_saved_queries(self) -> DocumentNode:
         return self._load("delete_saved_queries")
 
-    def configsdk_upload_mutation(self) -> DocumentNode:
+    def panthersdk_upload_mutation(self) -> DocumentNode:
         return self._load("sdk_upload")
 
     def _load(self, name: str) -> DocumentNode:
@@ -104,16 +109,10 @@ class PublicAPIClient(Client):
             for err in res.errors:
                 logging.error(err.message)
 
-            return BackendCheckResponse(
-                success=False,
-                message="connection check failed"
-            )
+            return BackendCheckResponse(success=False, message="connection check failed")
 
         if res.data is None:
-            return BackendCheckResponse(
-                success=False,
-                message="backend sent empty response"
-            )
+            return BackendCheckResponse(success=False, message="backend sent empty response")
 
         panther_version = res.data.get("generalSettings", {}).get("pantherVersion")
         if panther_version is None:
@@ -123,8 +122,7 @@ class PublicAPIClient(Client):
             )
 
         return BackendCheckResponse(
-            success=True,
-            message=f"connected to Panther backend on version: {panther_version}"
+            success=True, message=f"connected to Panther backend on version: {panther_version}"
         )
 
     def bulk_upload(self, params: BulkUploadParams) -> BackendResponse[BulkUploadResponse]:
@@ -144,20 +142,25 @@ class PublicAPIClient(Client):
         return BackendResponse(
             status_code=200,
             data=BulkUploadResponse(
-                rules=BulkUploadStatistics(**data.get('rules', default_stats)),
-                policies=BulkUploadStatistics(**data.get('policies', default_stats)),
-                data_models=BulkUploadStatistics(**data.get('dataModels', default_stats)),
-                lookup_tables=BulkUploadStatistics(**data.get('lookupTables', default_stats)),
-                global_helpers=BulkUploadStatistics(**data.get('globalHelpers', default_stats))
-            ))
+                rules=BulkUploadStatistics(**data.get("rules", default_stats)),
+                policies=BulkUploadStatistics(**data.get("policies", default_stats)),
+                data_models=BulkUploadStatistics(**data.get("dataModels", default_stats)),
+                lookup_tables=BulkUploadStatistics(**data.get("lookupTables", default_stats)),
+                global_helpers=BulkUploadStatistics(**data.get("globalHelpers", default_stats)),
+            ),
+        )
 
-    def delete_saved_queries(self, params: DeleteSavedQueriesParams) -> BackendResponse[DeleteSavedQueriesResponse]:
+    def delete_saved_queries(
+        self, params: DeleteSavedQueriesParams
+    ) -> BackendResponse[DeleteSavedQueriesResponse]:
         query = self._requests.delete_saved_queries()
-        delete_params = {"input": {
-            "dryRun": params.dry_run,
-            "includeDetections": params.include_detections,
-            "names": params.names,
-        }}
+        delete_params = {
+            "input": {
+                "dryRun": params.dry_run,
+                "includeDetections": params.include_detections,
+                "names": params.names,
+            }
+        }
         res = self._execute(query, variable_values=delete_params)
 
         if res.errors:
@@ -173,15 +176,17 @@ class PublicAPIClient(Client):
             data=DeleteSavedQueriesResponse(
                 names=data.get("names") or [],
                 detection_ids=data.get("detectionIDs") or [],
-            )
+            ),
         )
 
-    def delete_detections(self, params: DeleteDetectionsParams) -> BackendResponse[DeleteDetectionsResponse]:
+    def delete_detections(
+        self, params: DeleteDetectionsParams
+    ) -> BackendResponse[DeleteDetectionsResponse]:
         gql_params = {
             "input": {
                 "dryRun": params.dry_run,
                 "includeSavedQueries": params.include_saved_queries,
-                "ids": params.ids
+                "ids": params.ids,
             }
         }
         res = self._execute(self._requests.delete_detections_query(), gql_params)
@@ -199,12 +204,14 @@ class PublicAPIClient(Client):
         return BackendResponse(
             status_code=200,
             data=DeleteDetectionsResponse(
-                ids=data.get('ids') or [],
-                saved_query_names=data.get('savedQueryNames') or [],
-            )
+                ids=data.get("ids") or [],
+                saved_query_names=data.get("savedQueryNames") or [],
+            ),
         )
 
-    def list_managed_schemas(self, params: ListSchemasParams) -> BackendResponse[ListManagedSchemasResponse]:
+    def list_managed_schemas(
+        self, params: ListSchemasParams
+    ) -> BackendResponse[ListManagedSchemasResponse]:
         gql_params = {
             "input": {
                 "isManaged": params.is_managed,
@@ -220,26 +227,21 @@ class PublicAPIClient(Client):
             raise BackendError("empty data")
 
         schemas = []
-        for edge in res.data.get('schemas', {}).get('edges', []):
-            node = edge.get('node', {})
+        for edge in res.data.get("schemas", {}).get("edges", []):
+            node = edge.get("node", {})
             schema = ManagedSchema(
-                created_at=node.get('createdAt', ''),
-                description=node.get('description', ''),
-                is_managed=node.get('isManaged', False),
-                name=node.get('name', ''),
-                reference_url=node.get('referenceURL', ''),
-                revision=node.get('revision', ''),
-                spec=node.get('spec', ''),
-                updated_at=node.get('updatedAt', '')
+                created_at=node.get("createdAt", ""),
+                description=node.get("description", ""),
+                is_managed=node.get("isManaged", False),
+                name=node.get("name", ""),
+                reference_url=node.get("referenceURL", ""),
+                revision=node.get("revision", ""),
+                spec=node.get("spec", ""),
+                updated_at=node.get("updatedAt", ""),
             )
             schemas.append(schema)
 
-        return BackendResponse(
-                status_code=200,
-                data=ListManagedSchemasResponse(
-                    schemas=schemas
-                )
-            )
+        return BackendResponse(status_code=200, data=ListManagedSchemasResponse(schemas=schemas))
 
     def update_managed_schema(self, params: UpdateManagedSchemaParams) -> BackendResponse:
         gql_params = {
@@ -248,7 +250,7 @@ class PublicAPIClient(Client):
                 "name": params.name,
                 "referenceURL": params.reference_url,
                 "revision": params.revision,
-                "spec": params.spec
+                "spec": params.spec,
             }
         }
         res = self._execute(self._requests.update_schema_mutation(), gql_params)
@@ -260,31 +262,31 @@ class PublicAPIClient(Client):
         if res.data is None:
             raise BackendError("empty data")
 
-        schema = res.data.get('schema', {})
+        schema = res.data.get("schema", {})
         return BackendResponse(
             status_code=200,
             data=UpdateManagedSchemaResponse(
                 schema=ManagedSchema(
-                    created_at=schema.get('createdAt', ''),
-                    description=schema.get('description', ''),
-                    is_managed=schema.get('isManaged', False),
-                    name=schema.get('name', ''),
-                    reference_url=schema.get('referenceURL', ''),
-                    revision=schema.get('revision', ''),
-                    spec=schema.get('spec', ''),
-                    updated_at=schema.get('updatedAt', '')
+                    created_at=schema.get("createdAt", ""),
+                    description=schema.get("description", ""),
+                    is_managed=schema.get("isManaged", False),
+                    name=schema.get("name", ""),
+                    reference_url=schema.get("referenceURL", ""),
+                    revision=schema.get("revision", ""),
+                    spec=schema.get("spec", ""),
+                    updated_at=schema.get("updatedAt", ""),
                 )
-            )
+            ),
         )
 
-    def configsdk_bulk_upload(self, params: ConfigSDKBulkUploadParams) -> BackendResponse:
+    def panthersdk_bulk_upload(self, params: PantherSDKBulkUploadParams) -> BackendResponse:
         gql_params = {
             "input": {
                 "mode": "CONFIG_SDK",
-                "data": base64.b64encode(params.content.encode('utf-8')).decode('utf-8')
+                "data": base64.b64encode(params.content.encode("utf-8")).decode("utf-8"),
             }
         }
-        res = self._execute(self._requests.configsdk_upload_mutation(), gql_params)
+        res = self._execute(self._requests.panthersdk_upload_mutation(), gql_params)
         if res.errors:
             for err in res.errors:
                 logging.error(err.message)
@@ -293,32 +295,38 @@ class PublicAPIClient(Client):
         if res.data is None:
             raise BackendError("empty data")
 
-        rule_upload_stats = res.data.get('uploadDetectionEntities', {}).get('rules', {})
-        policy_upload_stats = res.data.get('uploadDetectionEntities', {}).get('policies', {})
-        query_upload_stats = res.data.get('uploadDetectionEntities', {}).get('queries', {})
+        rule_upload_stats = res.data.get("uploadDetectionEntities", {}).get("rules", {})
+        policy_upload_stats = res.data.get("uploadDetectionEntities", {}).get("policies", {})
+        query_upload_stats = res.data.get("uploadDetectionEntities", {}).get("queries", {})
         return BackendResponse(
             status_code=200,
-            data=ConfigSDKBulkUploadResponse(
+            data=PantherSDKBulkUploadResponse(
                 rules=BulkUploadStatistics(
                     modified=rule_upload_stats.get("modified"),
                     new=rule_upload_stats.get("new"),
-                    total=rule_upload_stats.get("total")
+                    total=rule_upload_stats.get("total"),
                 ),
                 policies=BulkUploadStatistics(
                     modified=policy_upload_stats.get("modified"),
                     new=policy_upload_stats.get("new"),
-                    total=policy_upload_stats.get("total")
+                    total=policy_upload_stats.get("total"),
                 ),
                 queries=BulkUploadStatistics(
                     modified=query_upload_stats.get("modified"),
                     new=query_upload_stats.get("new"),
-                    total=query_upload_stats.get("total")
-                )
-            )
+                    total=query_upload_stats.get("total"),
+                ),
+            ),
         )
 
-    def _execute(self, request: DocumentNode, variable_values: Optional[Dict[str, Any]] = None, ) -> ExecutionResult:
-        return self._gql_client.execute(request, variable_values=variable_values, get_execution_result=True)
+    def _execute(
+        self,
+        request: DocumentNode,
+        variable_values: Optional[Dict[str, Any]] = None,
+    ) -> ExecutionResult:
+        return self._gql_client.execute(
+            request, variable_values=variable_values, get_execution_result=True
+        )
 
 
 _API_URL_PATH = "public/graphql"
